@@ -3,5 +3,4 @@
 # Licensed under the MIT License. See License.txt in the project root for license information.
 # --------------------------------------------------------------------------------------------
 from azure.cli.core.breaking_change import register_argument_deprecate
-register_argument_deprecate('netappfiles volume create', '--endpoint-type')
-register_argument_deprecate('netappfiles volume update', '--endpoint-type')
+register_argument_deprecate('netappfiles volume update', '--remote-volume-resource-id')
