@@ -35,6 +35,7 @@ from azure.cli.command_modules.network._completers import (
 from azure.cli.command_modules.network._actions import (
     TrustedClientCertificateCreate,
     SslProfilesCreate, AddMappingRequest, WAFRulesCreate)
+from azure.cli.core.util import shell_safe_json_parse
 
 
 # pylint: disable=too-many-locals, too-many-branches, too-many-statements
@@ -781,6 +782,11 @@ def load_arguments(self, _):
         for item in ['vnet_gateway2', 'local_gateway2', 'express_route_circuit2']:
             c.argument(item, arg_group='Destination')
 
+        c.argument('auth_type', options_list=['--authentication-type', '--auth-type'], help='Authentication type for the VPN connection.', arg_type=get_enum_type(['Certificate', 'PSK']))
+        c.argument('cert_auth', options_list=['--certificate-authentication', '--cert-auth'],
+                   help='Certificate-based authentication configuration. Provide as JSON string or file path with @ prefix, Expected keys (outboundAuthCertificate, inboundAuthCertificateChain, inboundAuthCertificateSubjectName).',
+                   type=shell_safe_json_parse)
+
     with self.argument_context('network routeserver') as c:
         c.argument('virtual_hub_name', options_list=['--name', '-n'], id_part='name',
                    help='Name of the route server.')
@@ -837,3 +843,14 @@ def load_arguments(self, _):
             c.argument('resource_group_name', required=False)
             c.argument('resource_name', required=False, help='Name of the resource')
     # endregion
+
+    # region DdosCustomPolicy
+    with self.argument_context('network ddos-custom-policy create') as c:
+        c.argument('ddos_custom_policy_name', options_list=['--ddos-custom-policy-name', '--name', '-n'], help='The name of the DDoS custom policy.')
+        c.argument('location', arg_group='Parameters', help='Resource location.')
+        c.argument('tags', arg_group='Parameters', help='Resource tags.')
+        c.argument('detection_rule_name', arg_group='Detection Rules', help='The name of the DDoS detection rule.')
+        c.argument('detection_mode', arg_group='Detection Rules', help='The detection mode for the DDoS detection rule.')
+        c.argument('traffic_type', arg_group='Detection Rules', help='The traffic type (one of Tcp, Udp, TcpSyn) that the detection rule will be applied upon.')
+        c.argument('packets_per_second', arg_group='Detection Rules', help='The customized packets per second threshold.')
+    # endregion
