@@ -7,10 +7,13 @@ import json
 import os
 import re
 import importlib
+from enum import Enum
 
 from urllib.parse import urlparse
 
 from azure.cli.core.commands.arm import ArmTemplateBuilder
+from azure.cli.core.commands.client_factory import get_mgmt_service_client
+from azure.cli.core.profiles import ResourceType
 
 from knack.log import get_logger
 from knack.util import CLIError
@@ -32,7 +35,7 @@ def get_target_network_api(cli_ctx):
     if cli_ctx.cloud.profile == 'latest':
         version = '2022-01-01'
     else:
-        from azure.cli.core.profiles import get_api_version, ResourceType
+        from azure.cli.core.profiles import get_api_version
         version = get_api_version(cli_ctx, ResourceType.MGMT_NETWORK)
     return version
 
@@ -46,8 +49,6 @@ def read_content_if_is_file(string_or_file):
 
 
 def _resolve_api_version(cli_ctx, provider_namespace, resource_type, parent_path):
-    from azure.cli.core.commands.client_factory import get_mgmt_service_client
-    from azure.cli.core.profiles import ResourceType
     client = get_mgmt_service_client(cli_ctx, ResourceType.MGMT_RESOURCE_RESOURCES)
     provider = client.providers.get(provider_namespace)
 
@@ -73,12 +74,10 @@ def log_pprint_template(template):
 
 
 def check_existence(cli_ctx, value, resource_group, provider_namespace, resource_type,
-                    parent_name=None, parent_type=None):
+                    parent_name=None, parent_type=None, static_version=None):
     # check for name or ID and set the type flags
-    from azure.cli.core.commands.client_factory import get_mgmt_service_client
     from azure.core.exceptions import HttpResponseError
     from azure.mgmt.core.tools import parse_resource_id
-    from azure.cli.core.profiles import ResourceType
     id_parts = parse_resource_id(value)
     resource_client = get_mgmt_service_client(cli_ctx, ResourceType.MGMT_RESOURCE_RESOURCES,
                                               subscription_id=id_parts.get('subscription', None)).resources
@@ -93,7 +92,10 @@ def check_existence(cli_ctx, value, resource_group, provider_namespace, resource
         parent_path = ''
         resource_name = id_parts['name']
         resource_type = id_parts.get('type', resource_type)
+
     api_version = _resolve_api_version(cli_ctx, provider_namespace, resource_type, parent_path)
+    if static_version:  # only for vnet
+        api_version = static_version
 
     try:
         resource_client.get(rg, ns, parent_path, resource_type, resource_name, api_version)
@@ -118,19 +120,19 @@ def get_key_vault_base_url(cli_ctx, vault_name):
 
 
 def list_sku_info(cli_ctx, location=None):
-    from ._client_factory import _compute_client_factory
+    from .aaz.latest.vm import ListSkus as _ListSkus
 
     def _match_location(loc, locations):
-        return next((x for x in locations if x.lower() == loc.lower()), None)
+        return next((x for x in locations if str(x).lower() == str(loc).lower()), None)
 
-    client = _compute_client_factory(cli_ctx)
-    result = client.resource_skus.list()
+    result = _ListSkus(cli_ctx=cli_ctx)(command_args={})
     if location:
-        result = [r for r in result if _match_location(location, r.locations)]
+        result = [r for r in result if _match_location(location, r['locations'])]
     return result
 
 
-def is_sku_available(cmd, sku_info, zone):
+# pylint: disable=line-too-long
+def is_sku_available(sku_info, zone):
     """
     The SKU is unavailable in the following cases:
     1. regional restriction and the region is restricted
@@ -140,19 +142,15 @@ def is_sku_available(cmd, sku_info, zone):
     is_available = True
     is_restrict_zone = False
     is_restrict_location = False
-    if not sku_info.restrictions:
+    if not sku_info.get('restrictions', []):
         return is_available
-    for restriction in sku_info.restrictions:
-        if restriction.reason_code == 'NotAvailableForSubscription':
-            # The attribute location_info is not supported in versions 2017-03-30 and earlier
-            if cmd.supported_api_version(max_api='2017-03-30'):
-                is_available = False
-                break
-            if restriction.type == 'Zone' and not (
-                    set(sku_info.location_info[0].zones or []) - set(restriction.restriction_info.zones or [])):
+    for restriction in sku_info['restrictions']:
+        if restriction.get('reasonCode', '') == 'NotAvailableForSubscription':
+            if restriction['type'] == 'Zone' and not (
+                    set(sku_info['locationInfo'][0].get('zones', []) or []) - set(restriction['restrictionInfo'].get('zones', []) or [])):
                 is_restrict_zone = True
-            if restriction.type == 'Location' and (
-                    sku_info.location_info[0].location in (restriction.restriction_info.locations or [])):
+            if restriction['type'] == 'Location' and (
+                    sku_info['locationInfo'][0]['location'] in (restriction['restrictionInfo'].get('locations', []) or [])):
                 is_restrict_location = True
 
             if is_restrict_location or (is_restrict_zone and zone):
@@ -372,26 +370,34 @@ def update_disk_caching(model, caching_settings):
             _update(model, lun, value)
 
 
+def update_disk_caching_by_aaz(model, caching_settings):
+    def _update(model, lun, value):
+        luns = model.keys() if lun is None else [lun]
+        for lun_item in luns:
+            if lun_item not in model:
+                raise CLIError("Data disk with lun of '{}' doesn't exist. Existing luns: {}."
+                               .format(lun_item, list(model.keys())))
+            model[lun_item]['caching'] = value
+
+    if len(caching_settings) == 1 and '=' not in caching_settings[0]:
+        _update(model, None, caching_settings[0])
+    else:
+        for x in caching_settings:
+            if '=' not in x:
+                raise CLIError("usage error: please use 'LUN=VALUE' to configure caching on individual disk")
+            lun, value = x.split('=', 1)
+            lun = lun.lower()
+            lun = int(lun) if lun != 'os' else lun
+            _update(model, lun, value)
+
+
 def update_write_accelerator_settings(model, write_accelerator_settings):
     def _update(model, lun, value):
-        if isinstance(model, dict):
-            luns = model.keys() if lun is None else [lun]
-            for lun_item in luns:
-                if lun_item not in model:
-                    raise CLIError("data disk with lun of '{}' doesn't exist".format(lun_item))
-                model[lun_item]['writeAcceleratorEnabled'] = value
-        else:
-            if lun is None:
-                disks = [model.os_disk] + (model.data_disks or [])
-            elif lun == 'os':
-                disks = [model.os_disk]
-            else:
-                disk = next((d for d in model.data_disks if d.lun == lun), None)
-                if not disk:
-                    raise CLIError("data disk with lun of '{}' doesn't exist".format(lun))
-                disks = [disk]
-            for disk in disks:
-                disk.write_accelerator_enabled = value
+        luns = model.keys() if lun is None else [lun]
+        for lun_item in luns:
+            if lun_item not in model:
+                raise CLIError("data disk with lun of '{}' doesn't exist".format(lun_item))
+            model[lun_item]['write_accelerator_enabled'] = value
 
     if len(write_accelerator_settings) == 1 and '=' not in write_accelerator_settings[0]:
         _update(model, None, write_accelerator_settings[0].lower() == 'true')
@@ -407,8 +413,6 @@ def update_write_accelerator_settings(model, write_accelerator_settings):
 
 
 def get_storage_blob_uri(cli_ctx, storage):
-    from azure.cli.core.profiles._shared import ResourceType
-    from azure.cli.core.commands.client_factory import get_mgmt_service_client
     if urlparse(storage).scheme:
         storage_uri = storage
     else:
@@ -653,23 +657,20 @@ def validate_vm_disk_trusted_launch(namespace, disk_security_profile):
         return
 
     security_type = disk_security_profile.security_type if hasattr(disk_security_profile, 'security_type') else None
-    if security_type.lower() == 'trustedlaunch':
+    if security_type and security_type.lower() == 'trustedlaunch':
         if namespace.enable_secure_boot is None:
             namespace.enable_secure_boot = True
         if namespace.enable_vtpm is None:
             namespace.enable_vtpm = True
         namespace.security_type = 'TrustedLaunch'
-    elif security_type.lower() == 'standard':
+    elif security_type and security_type.lower() == 'standard':
         logger.warning(UPGRADE_SECURITY_HINT)
 
 
 def validate_image_trusted_launch(namespace):
     from ._constants import UPGRADE_SECURITY_HINT
 
-    # set securityType to Standard by default if no inputs by end user
-    if namespace.security_type is None:
-        namespace.security_type = 'Standard'
-    if namespace.security_type.lower() != 'trustedlaunch':
+    if namespace.security_type and namespace.security_type.lower() != 'trustedlaunch':
         logger.warning(UPGRADE_SECURITY_HINT)
 
 
@@ -753,3 +754,29 @@ def generate_ssh_keys_ed25519(private_key_filepath, public_key_filepath):
         f.write(public_bytes)
 
     return public_bytes.decode()
+
+
+def _gen_guid():
+    import uuid
+    return uuid.uuid4()
+
+
+def assign_identity(cli_ctx, getter, setter, identity_role=None, identity_scope=None):
+    from azure.cli.core.commands.arm import create_role_assignment
+
+    # get
+    resource = getter()
+    resource = setter(resource)
+
+    # create role assignment:
+    if identity_scope:
+        principal_id = resource.get('identity', {}).get('principalId') or resource.get('identity', {}).get('principal_id')
+        create_role_assignment(cli_ctx, principal_id, identity_role, identity_scope)
+    return resource
+
+
+class IdentityType(Enum):
+    SYSTEM_ASSIGNED = 'SystemAssigned'
+    USER_ASSIGNED = 'UserAssigned'
+    SYSTEM_ASSIGNED_USER_ASSIGNED = 'SystemAssigned, UserAssigned'
+    NONE = 'None'
